Fit TB-STATIS
fit_STATIS.RdEstimate maximum likelihood sequence for TB-STATIS. User must input the observed data, set of clinical states and measures to include in the model, and a vector of probabilities indicating the accuracy for each clinical measure.'fit_STATIS' returns the maximum likelihood sequence, and all log-likelihoods calculated during estimation.