Skip to contents

Generate a bar plot of the disease class distribution using the vector containing the predicted disease class for each individual after fitting TB-STATIS.

Usage

plot_class(pred_class = vector())

Arguments

pred_class

A vector of predicted disease classes.

Value

A ggplot object.