Skip to contents

Generate a line plot of the likelihood ascent from fitting TB-STATIS. The x-axis is the iteration number, the y-axis is the log-likelihood, and each line represents the log-likelihood at each iteration for a single initialized sequence.

Usage

plot_likes(likes = data.frame())

Arguments

likes

A data frame with three columns containing the log-likelihood for each iteration and each initialization.

Value

A ggplot object.