Skip to contents

Plot maximum likelihood sequence with sequences fit using bootstrap resampling to visualize uncertainty about maximum likelihood sequence.

Usage

pvd(boot_seqs = data.frame(), ml = data.frame())

Arguments

boot_seqs

A data frame of estimated sequences obtained from bootstrap resampling and estimating TB-STATIS on each resample.

ml

Maximum likelihood sequence from fitting TB-STATIS to original data.

Value

A ggplot object.