Disease class distribution
plot_class.RdGenerate a bar plot of the disease class distribution using the vector containing the predicted disease class for each individual after fitting TB-STATIS.
Usage
plot_class(pred_class = vector())plot_class.RdGenerate a bar plot of the disease class distribution using the vector containing the predicted disease class for each individual after fitting TB-STATIS.
plot_class(pred_class = vector())